# Host Information
Generated: {{vars.sys.date}}

## Identity
Fully Qualified Hostname: {{vars.sys.fqhost}}
Host ID: {{vars.sys.key_digest}}

## CFEngine
Version: CFEngine {{#classes.enterprise}}Enterprise{{/classes.enterprise}} {{vars.sys.cf_version}}
Last Agent Run: {{vars.host_info_report_cfengine.last_agent_run}}
Policy Release ID: {{vars.host_info_report_cfengine.cf_promises_release_id.releaseId}}
Policy Last Updated: {{vars.host_info_report_cfengine.cf_promises_validated_timestamp_formatted}}
Bootstrapped to: {{vars.sys.policy_hub}}

## OS
Architecture: {{vars.sys.arch}}
Os: {{vars.sys.os}}
Release: {{vars.sys.release}}
Flavor: {{vars.sys.flavor}}
Version: {{vars.sys.version}}
Uptime: {{vars.sys.uptime}} minutes

## Hardware
No. CPUs: {{vars.sys.cpus}}
{{! Redmine:4505 https://cfengine.com/dev/issues/4505 }}

## Network

### Interfaces
{{#vars.host_info_report_cfengine.interface_info}}
  * {{.}}
{{/vars.host_info_report_cfengine.interface_info}}

{{! Redmine:4506 https://cfengine.com/dev/issues/4506 }}
### IPv4 TCP Ports listening
{{#vars.mon.listening_tcp4_ports}}
  * {{.}}
{{/vars.mon.listening_tcp4_ports}}

{{#classes.show_software}}
{{! Redmine:4507 https://cfengine.com/dev/issues/4507 }}
## Software
{{#vars.host_info_report_software.packages}}
[{{method}}] {{name}}: version {{version}}, arch {{arch}}
{{/vars.host_info_report_software.packages}}
{{/classes.show_software}}
